==> physical_validation-1.0.4.tar.gz: physical_validation-1.0.4/README.md <==
[![GitHub Actions Test Status](https://github.com/shirtsgroup/physical_validation/actions/workflows/continous_integration.yaml/badge.svg)](https://github.com/shirtsgroup/physical_validation/actions/workflows/continous_integration.yaml)
[![GitHub Actions Lint Status](https://github.com/shirtsgroup/physical_validation/actions/workflows/lint.yaml/badge.svg)](https://github.com/shirtsgroup/physical_validation/actions/workflows/lint.yaml)
[![Documentation Status](https://readthedocs.org/projects/physical-validation/badge/?version=latest)](https://physical-validation.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/shirtsgroup/physical_validation/branch/master/graph/badge.svg)](https://codecov.io/gh/shirtsgroup/physical_validation)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/shirtsgroup/physical_validation.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/shirtsgroup/physical_validation/context:python)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/shirtsgroup/physical_validation.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/shirtsgroup/physical_validation/alerts/)  
[![DOI](https://zenodo.org/badge/90674371.svg)](https://zenodo.org/badge/latestdoi/90674371)  
[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)

physical_validation: A Python package to assess the physical validity of molecular simulation results
=====================================================================================================

`physical_validation` is a package testing results obtained by molecular simulations for their physical validity.

Please cite 
> Merz PT, Shirts MR (2018) Testing for physical validity in molecular simulations. PLoS ONE 13(9): e0202764. https://doi.org/10.1371/journal.pone.0202764

`physical_validation` incorporates the functionality of [checkensemble](https://github.com/shirtsgroup/checkensemble).

This software is developed in the Shirts group at University of Colorado in Boulder.

Documentation
-------------
Please check
[https://physical-validation.readthedocs.io](http://physical-validation.readthedocs.io)
for the full reference.

==> physical_validation-1.0.5.tar.gz: physical_validation-1.0.5/README.md <==
[![GitHub Actions Test Status](https://github.com/shirtsgroup/physical_validation/actions/workflows/continous_integration.yaml/badge.svg)](https://github.com/shirtsgroup/physical_validation/actions/workflows/continous_integration.yaml)
[![GitHub Actions Lint Status](https://github.com/shirtsgroup/physical_validation/actions/workflows/lint.yaml/badge.svg)](https://github.com/shirtsgroup/physical_validation/actions/workflows/lint.yaml)
[![Documentation Status](https://readthedocs.org/projects/physical-validation/badge/?version=latest)](https://physical-validation.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/shirtsgroup/physical_validation/branch/master/graph/badge.svg)](https://codecov.io/gh/shirtsgroup/physical_validation)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/shirtsgroup/physical_validation.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/shirtsgroup/physical_validation/context:python)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/shirtsgroup/physical_validation.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/shirtsgroup/physical_validation/alerts/)  
[![DOI](https://zenodo.org/badge/90674371.svg)](https://zenodo.org/badge/latestdoi/90674371) [![DOI](https://joss.theoj.org/papers/10.21105/joss.03981/status.svg)](https://doi.org/10.21105/joss.03981)  
[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)

physical_validation: A Python package to assess the physical validity of molecular simulation results
=====================================================================================================

`physical_validation` is a package testing results obtained by molecular simulations for their physical validity.

Please cite 
> Merz PT, Shirts MR (2018) Testing for physical validity in molecular simulations. PLoS ONE 13(9): e0202764. https://doi.org/10.1371/journal.pone.0202764  
> Merz et al., (2022). physical_validation: A Python package to assess the physical validity of molecular simulation results. Journal of Open Source Software, 7(69), 3981, https://doi.org/10.21105/joss.03981

`physical_validation` incorporates the functionality of [checkensemble](https://github.com/shirtsgroup/checkensemble).

This software is developed in the Shirts group at University of Colorado in Boulder.

Documentation
-------------
Please check
[https://physical-validation.readthedocs.io](http://physical-validation.readthedocs.io)
for the full reference.
